@@ -1,17 +1,20 @@
 #' Build a synthetic block-structured temporal data with breaks
 #'
-#' MakeBlockNetworkChange generates a block-structured temporal data with breaks
+#' MakeBlockNetworkChange generates a block-structured temporal data with breaks.
 #'
 #'
 #' @param n The number of nodes within a block. The total number of nodes is n*block.number.
 #'
 #' @param break.point The point of break. 0 indicates the beginning, 0.5 indicates the middle,
 #' and 1 indicates the end. 
-#' @param block.number The number of blocks.
+#' @param break.point1 The point of the first break in "merge-split" or "split-merge". Any number between 0 and 0.5 can be chosen.
+#' For example, 0 indicates #' the beginning, 0.25 indicates the 1/4th point, and 0.5 indicates the half point. 
+#' @param break.point2 The point of the second breakin "merge-split" or "split-merge". Any number between 0.5 and 1 can be chosen.
+#' For example, 0.5 indicates the beginning, 0.75 indicates the 3/4th point, and 1 indicates the end point. 
 #' @param base.prob The probability of link among non-block members.
 #' @param block.prob The probability of link among within-block members.
 #' @param shape The speed of breaks.
-#' The larger shape is, the faster the transition is. 0 is the minimum. 
+#' The larger shape is, the faster the transition is. shape > 0 and shape < 8. 
 #' @param T The length of time.
 #' @param type The type of network changes. Options are "constant", "merge", "split",
 #' "merge-split", "split-merge." If "constant" is chosen, the number of breaks is zero.
@@ -24,34 +27,37 @@
 #'
 #'
 
-MakeBlockNetworkChange <- function(n=10, break.point = .5, 
-                                   block.number = 3, base.prob=.05, block.prob=.5,
-                                   shape=10, T=40, 
+MakeBlockNetworkChange <- function(n=10, break.point = 0.5, 
+                                   base.prob=.05, block.prob=.5,
+                                   shape=1, T= 40, break.point1 = 0.25, break.point2 = 0.75,
                                    type ="merge" 
                                    ){
     call <- match.call()
+    block.number = 3
     N <- block.number*n
     cpn = block.number -1
 
     b0 <- matrix(1, n, n)
-    intercept <- -20 + 40*break.point
-    x = seq(-20,20,length=T)
-    sv = (1/(1+exp(intercept - shape*x))-1/(1+exp(intercept - shape*min(x))))/
-        (1/(1+exp(intercept - shape*max(x)))-1/(1+exp(intercept - shape*min(x))))*n
+    x = seq(-20, 20, length=T)
+    intercept <- as.numeric(quantile(x, probs=break.point))
+    sv = (1/(1+exp(intercept*shape - shape*x))-1/(1+exp(intercept*shape - shape*min(x))))*n
+        ## (1/(1+exp(intercept - shape*max(x)))-1/(1+exp(intercept - shape*min(x))))
+    ## plot(sv)
+    
     if(type == "split-merge" |type ==  "merge-split"){
-        break.point1 <- .50
-        intercept1 <- -20 + 40*break.point1
+        ## break.point1 <- .50
         end <- ceiling(T/2)
         x1 = seq(-20,20,length=end)
-        sv1 = (1/(1+exp(intercept1 - shape*x1))-1/(1+exp(intercept1 - shape*min(x1))))/
-            (1/(1+exp(intercept1 - shape*max(x1)))-1/(1+exp(intercept1 - shape*min(x1))))*n
+        intercept1 <- as.numeric(quantile(x1, probs=break.point1/0.5))
+        sv1 = (1/(1+exp(intercept1*shape - shape*x1))-1/(1+exp(intercept1*shape - shape*min(x1))))*n
+        ## (1/(1+exp(intercept1*shape - shape*max(x1)))-1/(1+exp(intercept1*shape - shape*min(x1))))*n
         sv.split <- round(sort(sv1))
         
-        break.point2<- .50
-        intercept2 <- -20 + 40*break.point2
-        x2 = seq(-20,20,length=(T - end))
-        sv2 = (1/(1+exp(intercept2 - shape*x2))-1/(1+exp(intercept2 - shape*min(x2))))/
-            (1/(1+exp(intercept2 - shape*max(x2)))-1/(1+exp(intercept2 - shape*min(x2))))*n
+        ## break.point2<- .50
+        x2 = seq(-20,20, length=(T - end))
+        intercept2 <- as.numeric(quantile(x2, probs=(break.point2 - 0.5)/0.5))
+        sv2 = (1/(1+exp(intercept2*shape - shape*x2))-1/(1+exp(intercept2*shape - shape*min(x2))))*n
+            ## (1/(1+exp(intercept2*shape - shape*max(x2)))-1/(1+exp(intercept2*shape - shape*min(x2))))*n
         sv.merge <- round(sort(sv2, decreasing=TRUE))
     }
 
@@ -61,8 +67,8 @@ MakeBlockNetworkChange <- function(n=10, break.point = .5,
         sv <- sort(sv, decreasing=TRUE)
         for (t in 1:T){
             ## heterohpilic block till t<tp; homophilic blcok from t=tp         
-            b1=matrix(1,sv[t],sv[t])
-            b2=matrix(1,2*n-sv[t],2*n-sv[t])
+            b1=matrix(1, sv[t], sv[t])
+            b2=matrix(1, 2*n-sv[t], 2*n-sv[t])
             
             ## initial block structure with three homophilic groups
             B=rbind(cbind(matrix(1,sv[t],sv[t]), matrix(0,sv[t],2*n-sv[t]),matrix(0,sv[t],n)),
@@ -154,7 +160,7 @@ MakeBlockNetworkChange <- function(n=10, break.point = .5,
         }
   
     } else if(type == "constant"){
-        sv <- rep(1, length(sv))
+        sv <- rep(max(sv), length(sv))
         for (t in 1:T){
             ## heterohpilic block till t<tp; homophilic blcok from t=tp         
             b1=matrix(1,sv[t],sv[t])
